==> qt-creator-opensource-src-4.0.0.zip: qt-creator-opensource-src-4.0.0/src/plugins/coreplugin/externaltoolmanager.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef EXTERNALTOOLMANAGER_H
#define EXTERNALTOOLMANAGER_H

#include "core_global.h"

#include <QObject>
#include <QMap>
#include <QList>
#include <QString>

namespace Core {

namespace Internal { class ExternalTool; }

class CORE_EXPORT ExternalToolManager : public QObject
{
    Q_OBJECT

public:
    ExternalToolManager();
    ~ExternalToolManager();

    static ExternalToolManager *instance();
    static QMap<QString, QList<Internal::ExternalTool *> > toolsByCategory();
    static QMap<QString, Internal::ExternalTool *> toolsById();
    static void setToolsByCategory(const QMap<QString, QList<Internal::ExternalTool *> > &tools);
    static void emitReplaceSelectionRequested(const QString &output);

signals:
    void replaceSelectionRequested(const QString &text);
};

} // namespace Core


#endif // EXTERNALTOOLMANAGER_H

==> qt-creator-opensource-src-4.2.2.zip: qt-creator-opensource-src-4.2.2/src/plugins/coreplugin/externaltoolmanager.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "core_global.h"

#include <QObject>
#include <QMap>
#include <QList>
#include <QString>

namespace Core {

namespace Internal { class ExternalTool; }

class CORE_EXPORT ExternalToolManager : public QObject
{
    Q_OBJECT

public:
    ExternalToolManager();
    ~ExternalToolManager();

    static ExternalToolManager *instance();
    static QMap<QString, QList<Internal::ExternalTool *> > toolsByCategory();
    static QMap<QString, Internal::ExternalTool *> toolsById();
    static void setToolsByCategory(const QMap<QString, QList<Internal::ExternalTool *> > &tools);
    static void emitReplaceSelectionRequested(const QString &output);

signals:
    void replaceSelectionRequested(const QString &text);
};

} // namespace Core
